( cd usr/lib64 ; rm -rf libaprutil-1.so.0 )
( cd usr/lib64 ; ln -sf libaprutil-1.so.0.3.9 libaprutil-1.so.0 )
( cd usr/lib64 ; rm -rf libaprutil-1.so )
( cd usr/lib64 ; ln -sf libaprutil-1.so.0.3.9 libaprutil-1.so )
